@@ -16,14 +16,14 @@
 #ifndef LIBRADIUS_H
 #define LIBRADIUS_H
 /*
- * $Id: e5f2251949b5f9d2525da8303b0cbbfd16a2872a $
+ * $Id: 4dda31ced645438d4c2de1a5d7f47f860dc220d3 $
  *
  * @file libradius.h
  * @brief Structures and prototypes for the radius library.
  *
  * @copyright 1999-2014 The FreeRADIUS server project
  */
-RCSIDH(libradius_h, "$Id: e5f2251949b5f9d2525da8303b0cbbfd16a2872a $")
+RCSIDH(libradius_h, "$Id: 4dda31ced645438d4c2de1a5d7f47f860dc220d3 $")
 
 /*
  *  Compiler hinting macros.  Included here for 3rd party consumers
@@ -407,6 +407,14 @@ typedef struct radius_packet {
 	size_t			partial;
 	int			proto;
 #endif
+#ifdef WITH_RADIUSV11
+	bool			radiusv11;
+#endif
+	bool			tls;		//!< uses secure transport
+
+	bool			message_authenticator;
+	bool			proxy_state;
+	bool			eap_message;
 } RADIUS_PACKET;
 
 typedef enum {
@@ -427,6 +435,16 @@ typedef enum {
 	DECODE_FAIL_MAX
 } decode_fail_t;
 
+#ifdef WITH_RADIUSV11
+typedef enum {
+       FR_RADIUSV11_FORBID = 0,
+       FR_RADIUSV11_ALLOW,
+       FR_RADIUSV11_REQUIRE,
+} fr_radiusv11_t;
+
+extern const FR_NAME_NUMBER radiusv11_types[];
+#endif
+
 /*
  *	Version check.
  */
@@ -514,6 +532,13 @@ DICT_VENDOR	*dict_vendorbyvalue(int vendor);
 /* radius.c */
 int		rad_send(RADIUS_PACKET *, RADIUS_PACKET const *, char const *secret);
 bool		rad_packet_ok(RADIUS_PACKET *packet, int flags, decode_fail_t *reason);
+
+/*
+ *	1 == require_ma
+ *	2 == msg_peek
+ *	4 == limit_proxy_state
+ *	8 == require_ma for Access-* replies and Protocol-Error
+ */
 RADIUS_PACKET	*rad_recv(TALLOC_CTX *ctx, int fd, int flags);
 ssize_t rad_recv_header(int sockfd, fr_ipaddr_t *src_ipaddr, uint16_t *src_port, int *code);
 void		rad_recv_discard(int sockfd);
@@ -531,6 +556,8 @@ RADIUS_PACKET	*rad_alloc_reply(TALLOC_CTX *ctx, RADIUS_PACKET *);
 RADIUS_PACKET *rad_copy_packet(TALLOC_CTX *ctx, RADIUS_PACKET const *in);
 
 void		rad_free(RADIUS_PACKET **);
+
+#ifndef WITH_RADIUSV11_ONLY
 int		rad_pwencode(char *encpw, size_t *len, char const *secret,
 			     uint8_t const *vector);
 int		rad_pwdecode(char *encpw, size_t len, char const *secret,
@@ -543,6 +570,7 @@ ssize_t		rad_tunnel_pwdecode(uint8_t *encpw, size_t *len,
 				    char const *secret, uint8_t const *vector);
 int		rad_chap_encode(RADIUS_PACKET *packet, uint8_t *output,
 				int id, VALUE_PAIR *password);
+#endif
 
 int		rad_attr_ok(RADIUS_PACKET const *packet, RADIUS_PACKET const *original,
 			    DICT_ATTR *da, uint8_t const *data, size_t length);
@@ -704,7 +732,7 @@ extern bool	fr_dns_lookups;	/* do IP -> hostname lookups? */
 extern bool	fr_hostname_lookups; /* do hostname -> IP lookups? */
 extern int	fr_debug_lvl;	/* 0 = no debugging information */
 extern uint32_t	fr_max_attributes; /* per incoming packet */
-#define	FR_MAX_PACKET_CODE (52)
+#define	FR_MAX_PACKET_CODE (53)
 extern char const *fr_packet_codes[FR_MAX_PACKET_CODE];
 #define is_radius_code(_x) ((_x > 0) && (_x < FR_MAX_PACKET_CODE))
 extern FILE	*fr_log_fp;
@@ -899,6 +927,7 @@ rbnode_t	*rbtree_find(rbtree_t *tree, void const *data);
 void		*rbtree_finddata(rbtree_t *tree, void const *data);
 uint32_t	rbtree_num_elements(rbtree_t *tree);
 void		*rbtree_node2data(rbtree_t *tree, rbnode_t *node);
+void		*rbtree_first(rbtree_t *tree);
 
 /*
  *	The callback should be declared as:
@@ -942,6 +971,12 @@ int		fr_socket_wait_for_connect(int sockfd, struct timeval *timeout);
 }
 #endif
 
+typedef enum {
+	FR_BOOL_FALSE = 0,
+	FR_BOOL_TRUE,
+	FR_BOOL_AUTO,
+} fr_bool_auto_t;
+
 #include <freeradius/packet.h>
 
 #ifdef WITH_TCP
